# CHANGELOG

## v0.1.1 [28 October 2024]

- Minor updates to examples for NAWEA workshop

## v0.1 [16 October 2024]

- Project has been separated from HOPP and moved into GreenHEART, removing all HOPP infrastructure.
